(function (global) {
    "use strict";
    //reupload test
    global.ND = global.ND || {};
    global.ND.Portal = global.ND.Portal || {};
    global.ND.Portal.SurfaceTractDetailsFormLogic = (function () {
	
		var handleFormOnLoad = (event) => {
			$('.tab-title').hide();
			
			_initializeSubgrids();
			_populateSubgrids();
			$("fieldset[aria-label='Right of Way Agreements'] .custom-core-pagination").attr("id","rowAgreements-page-list-custom");
			$("fieldset[aria-label='Lease Agreements'] .custom-core-pagination").attr("id","leaseAgreements-page-list-custom");
		}

		var _initializeSubgrids = () => {
            ND.Portal.Tables.renderSubgrid('leaseAgreementsSection', 'Lease Agreements');
            ND.Portal.Tables.renderSubgrid('landUnitsSection', 'Tracts Required for Lease Agreement');
            ND.Portal.Tables.renderSubgrid('rowAgreementsSection', 'Right of Way Agreements');
            ND.Portal.Tables.renderSubgrid('leaseProvisionsSection', 'Lease Provisions');
            ND.Portal.Tables.renderSubgrid('tractTrustsSection', 'Tract Trusts');
		};
        
		var _currentLeaseProvisionsPage = 1;
		var _currentTractTrustsPage = 1;
		var _currentLeaseAgreementsPage = 1;
		var _currentLandUnitsPage = 1;
		var _currentRowAgreementsPage = 1;
		var _populateSubgrids = () => {
			_handlePageToggle(1, _currentRowAgreementsPage, "rowAgreements", _createRowAgreementRow, "ND Service: Get ROW Agreements By Surface Tract", TractsConfigurations);
			_handlePageToggle(1, _currentLeaseAgreementsPage, "leaseAgreements", _createLeaseAgreementRow, "ND Service: Get Lease Agreements By Surface Tract", TractsConfigurations);
			_handlePageToggle(1, _currentLeaseProvisionsPage, "leaseProvisions", _createLeaseProvisionRow, "ND Service: Get Lease Provisions By Surface Tract", TractsConfigurations);
			_handlePageToggle(1, _currentTractTrustsPage, "tractTrusts", _createTractTrustRow, "ND Service: Get Tract Trusts By Surface Tract", TractsConfigurations);
			_handlePageToggle(1, _currentLandUnitsPage, "landUnits", _createLandUnitsRow, "ND Service: Get Land Units By Surface Tract", TractsConfigurations);
		}
		
		var _createLeaseAgreementRow = (result) => {
			return `
				<tr>
					<td class="title" data-th="Lease Agreement">
						<a href="/surface-lease-agreements/details?id=${result.Id}">${result.LeaseAgreement}</a>
					</td>
					<td data-th="Type">
						${result.Type || "&ndash;"}
					</td>
					<td data-th="Primary Lessee">
						${result.Lessee || "&ndash;"}
					</td>
					<td data-th="Annual Rent">
						${result.AnnualRent || "&ndash;"}
					</td>
					<td data-th="Expiration Date">
						${result.ExpirationDate || "&ndash;"}
					</td>
				</tr>`;
		};
		
		var _createLandUnitsRow = (result) => {
			return `
				<tr>
					<td data-th="Tracts">
						<a href="/surface-tracts/details?id=${result.Id}">${result.Tract}</a>
					</td>
				</tr>`;
		};
		
		var _createRowAgreementRow = (result) => {
			return `
				<tr>
					<td data-th="Agreement #">
						<a href="/right-of-way-agreements/details?id=${result.Id}" >${result.Agreement}</a>
					</td>
					<td data-th="Agreement Type">
						${result.AgreementType || "&ndash;"}
					</td>
					<td data-th="Project Type">
						${result.ProjectType || "&ndash;"}
					</td>
					<td data-th="Issued Date">
						${result.IssuedDate || "&ndash;"}
					</td>
				</tr>`;
		};
		
		var _createLeaseProvisionRow = (result) => {
			return `
				<tr>
					<td data-th="Type">
						${result.Type}
					</td>
				</tr>`;
		};

		var _createTractTrustRow = (result) => {
			return `
				<tr>
					<td data-th="Trust">
						${result.Trust}
					</td>
					<td data-th="Trust Description">
						${result.TrustDescription || "&ndash;"}
					</td>
				</tr>`;
		};

		var _handlePageToggle = function(selectedPage, _currentRowAgreementsPage, tableName, createRowFunction, serviceEndpointName, tableConfiguration) {
			const urlParams = new URLSearchParams(window.location.search);
			const id = urlParams.get('id');
			
			var requestUrl = `/Services?name=${serviceEndpointName}&count=10&page={0}&id=${id}`;
			const tableSettings = TractsConfigurations["rowAgreements"];
			const orderOn = tableSettings?.OrderingConfiguration?.OrderOn;
			if (orderOn) {
				const orderBy = tableSettings?.OrderingConfiguration?.OrderBy || "ascending";
				requestUrl += `&orderOn=${orderOn}&orderBy=${orderBy}`;
			}

			_currentRowAgreementsPage = ND.Portal.Tables.handleTablePaging(_currentRowAgreementsPage,
				selectedPage,
				requestUrl,
				tableName,
				createRowFunction,
				(selectedPage) => _handlePageToggle(selectedPage, _currentRowAgreementsPage, tableName, createRowFunction, serviceEndpointName, tableConfiguration),
				tableConfiguration);
		}

		const TractsConfigurations = {
            "rowAgreements": {
                PagingCallback: _handlePageToggle,
                GetCurrentPage: () => { return _currentRowAgreementsPage; },
                OrderingConfiguration: {
                    OrderOn: "eyland_tractlegallocationname",
                    OrderBy: "descending"
                }
            },
			"leaseAgreements": {
                PagingCallback: _handlePageToggle,
                GetCurrentPage: () => { return _currentLeaseAgreementsPage; },
                OrderingConfiguration: {
                    OrderOn: "eyland_tractlegallocationname",
                    OrderBy: "descending"
                }
            },
			"leaseProvisions": {
                PagingCallback: _handlePageToggle,
                GetCurrentPage: () => { return _currentLeaseAgreementsPage; },
                OrderingConfiguration: {
                    OrderOn: "eyland_tractlegallocationname",
                    OrderBy: "descending"
                }
            },
			"tractTrusts": {
                PagingCallback: _handlePageToggle,
                GetCurrentPage: () => { return _currentTractTrustsPage; },
                OrderingConfiguration: {
                    OrderOn: "eyland_tractlegallocationname",
                    OrderBy: "descending"
                }
            },
			"landUnits": {
                PagingCallback: _handlePageToggle,
                GetCurrentPage: () => { return _currentLandUnitsPage; },
                OrderingConfiguration: {
                    OrderOn: "eyland_tractlegallocationname",
                    OrderBy: "descending"
                }
            }
        };

		
		return {
            handleFormOnLoad: handleFormOnLoad,
        };
    })();
})(this);